"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_2 = require("@chakra-ui/react");
const mapbox_gl_1 = __importDefault(require("mapbox-gl"));
const generateId_1 = require("./utils/generateId");
const deleteLayersById_1 = __importDefault(require("./utils/deleteLayersById"));
const layerLayout_1 = require("./data/layer/style/layerLayout");
const MapComponent_1 = __importDefault(require("./MapComponent"));
const useMapEvents_1 = __importDefault(require("./hooks/useMapEvents"));
mapbox_gl_1.default.accessToken = "pk.eyJ1Ijoia2Fpbi1ldmFtIiwiYSI6ImNsb3lhczE5eDAyMDIya2xtcHFwczFlZTgifQ.arDGvCMwYNu80PElCsm7sQ"; //TODO fix this before merge
const MapDrawer = () => {
    const mapContainer = (0, react_1.useRef)(null);
    const map = (0, react_1.useRef)(null);
    const [lng, setLng] = (0, react_1.useState)(17.972534);
    const [lat, setLat] = (0, react_1.useState)(59.352032);
    const [zoom, setZoom] = (0, react_1.useState)(7);
    const deleteAllLayersById = (0, react_1.useCallback)((id) => (0, deleteLayersById_1.default)(map, id), []);
    const handleNavLayerDeleted = (0, react_1.useCallback)((e) => {
        if (map.current) {
            const id = e.detail;
            if (typeof id === "string")
                deleteAllLayersById(id);
        }
    }, [deleteAllLayersById]);
    const handleNavLayerShapeSet = (0, react_1.useCallback)((e) => {
        if (map.current) {
            const detail = e.detail;
            if (detail === undefined)
                return;
            const id = detail.id;
            const layerData = detail.layerData;
            //validate data
            if (typeof id === "string" && Array.isArray(layerData)) {
                deleteAllLayersById(id);
                const layerDataArray = layerData;
                const geoJsonFeatureCollection = (0, layerLayout_1.generateShapeNavLayerGeoJsonFeatures)(layerDataArray);
                geoJsonFeatureCollection.forEach((geoJsonFeature, index) => {
                    const { sourceId, layerId, labelId } = (0, generateId_1.generateIds)(id, index);
                    const geojson = {
                        type: "geojson",
                        data: {
                            type: "FeatureCollection",
                            features: [geoJsonFeature]
                        }
                    };
                    const source = map.current.getSource(sourceId);
                    if (!source)
                        map.current.addSource(sourceId, geojson);
                    const existingLayer = map.current.getLayer(layerId);
                    if (!existingLayer)
                        map.current.addLayer((0, layerLayout_1.generateFillLayer)(layerId, sourceId));
                    const existingLabel = map.current.getLayer(labelId);
                    // Add text label
                    if (!existingLabel)
                        map.current.addLayer((0, layerLayout_1.generateTextLayer)(labelId, sourceId));
                });
            }
        }
    }, [deleteAllLayersById]);
    const handleNavLayerPointSet = (0, react_1.useCallback)((e) => {
        if (map.current) {
            const detail = e.detail;
            if (detail === undefined)
                return;
            const id = detail.id;
            const layerData = detail.layerData;
            //validate data
            if (typeof id === "string" && Array.isArray(layerData)) {
                deleteAllLayersById(id);
                const layerDataArray = layerData;
                const geojsonFeatures = (0, layerLayout_1.generatePointsNavLayerGeoJsonFeatures)(layerDataArray);
                const geojson = (0, layerLayout_1.generateGeoJsonPointsLayerFromFeatures)(geojsonFeatures);
                map.current.loadImage(layerDataArray.at(0).icon, (error, image) => {
                    if (error)
                        throw error;
                    const { imageId, sourceId, layerId } = (0, generateId_1.generateIds)(id);
                    const hasImage = map.current.hasImage(imageId);
                    if (!hasImage)
                        map.current.addImage(imageId, image);
                    const source = map.current.getSource(sourceId);
                    if (!source)
                        map.current.addSource(sourceId, geojson);
                    const existingLayer = map.current.getLayer(layerId);
                    if (!existingLayer)
                        map.current.addLayer((0, layerLayout_1.generateImageLayer)(layerId, sourceId, imageId));
                });
            }
        }
    }, [deleteAllLayersById]);
    (0, useMapEvents_1.default)({
        onNavLayerPointSet: handleNavLayerPointSet,
        onNavLayerDeleted: handleNavLayerDeleted,
        onNavLayerShapeSet: handleNavLayerShapeSet
    });
    (0, react_1.useEffect)(() => {
        if (map.current)
            return;
        /**
         This timeout is here because the Mapbox tutorial for React is slightly wrong.
         The reason is that once we get to this line there's no way to know that mapContainer.current !== null
         and if it is equal to null then setting it as the container will throw an error.
    
         4000ms should be sufficient time for the div to mount and mapContainer.current to be of the right type.
         It's a "bodged" approach, but should work for now.
    
         Just because this useEffect has no dependencies doesn't mean it will trigger when ref value updates. Refs
         do not cause re-rendering.
         */
        const id = setTimeout(() => {
            map.current = new mapbox_gl_1.default.Map({
                container: mapContainer.current,
                style: "mapbox://styles/mapbox/streets-v12",
                center: [lng, lat],
                zoom: zoom
            });
            map.current.on("zoomend", (d) => {
                setZoom(parseInt(d.target.getZoom().toString()));
            });
            map.current.on("moveend", (d) => {
                setLat(d.target.getCenter().lat);
                setLng(d.target.getCenter().lng);
            });
        }, 5000);
        return () => clearTimeout(id);
    });
    return (0, jsx_runtime_1.jsx)(react_2.Box, { pos: "fixed", opacity: 0.76, _hover: {
            opacity: 1
        }, right: 4, bottom: 4, children: (0, jsx_runtime_1.jsx)(MapComponent_1.default, { ref: mapContainer, style: {
                height: "500px",
                width: "40vh"
            } }) });
};
exports.default = MapDrawer;
//# sourceMappingURL=MapDrawer.js.map