"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Notification = void 0;
/**
 * {
 *
 *     "heading":"My notification",
 *
 *     "description":"Description",
 *
 *     "primaryButtonText":"Button 1",
 *
 *     "secondaryButtonText":"Button 2",
 *
 *     "notificationType":"QUICK_HUN", // CONCEALED_HUN, LIMITED_HUN, QUICK_HUN, LASTING_HUN, ACTION_HUN default: QUICK_HUN
 *
 * }
 */
const NotificationType_1 = require("./NotificationType");
class NotificationButton {
    constructor(label, callback) {
        this.label = label;
        this.callback = callback;
    }
    static fromJSON(notificationButton) {
        if (notificationButton.label === undefined) {
            throw Error('label must be defined in fromJSON for notificationButton');
        }
        return new NotificationButton(notificationButton.label, notificationButton.callback);
    }
}
class Notification {
    /**
     * Notification to appear in vehicle services
     * @param notificationId unique notification id that is optional and used if the app also needs to remove a notification
     * @param heading the main title of the notification
     * @param description extra detail regarding the notification
     * @param notificationType how the notification is displayed
     * @param primaryButton primary button label and optional callback
     * @param secondaryButton optional secondary button label and optional callback
     */
    constructor(heading, description, notificationType, primaryButton, secondaryButton, notificationId) {
        this.heading = heading;
        this.description = description;
        this.notificationType = notificationType;
        this.primaryButton = primaryButton;
        this.secondaryButton = secondaryButton;
        this.notificationId = notificationId;
    }
    static fromJSON(notification) {
        if (notification.heading === undefined || notification.description === undefined || notification.notificationType === undefined) {
            throw Error("heading, description and notificationType must be specified in notification fromJSON");
        }
        let convertedNotificationType;
        try {
            convertedNotificationType = NotificationType_1.NotificationType[notification.notificationType];
        }
        catch {
            throw Error("Invalid notification type in fromJSON for notification");
        }
        return new Notification(notification.heading, notification.description, convertedNotificationType, NotificationButton.fromJSON(notification.primaryButton), notification.secondaryButton ? NotificationButton.fromJSON(notification.secondaryButton) : undefined, notification.notificationId || undefined);
    }
}
exports.Notification = Notification;
//# sourceMappingURL=Notification.js.map