import { VehicleStatus } from "./VehicleStatus";
import { DestinationSiteLocation } from "./DestinationSiteLocation";
import { DestinationControlPointLocation } from "./DestinationControlPointLocation";
import { HospitalLocation } from "./HospitalLocation";
import { OperationPriority } from "./OperationPriority";
import { OperationState } from "./OperationState";
import { LeavePatientLocation } from "./LeavePatientLocation";
import { OperationUnit } from "./OperationUnit";
declare class Operation {
    operationID: string;
    name: string;
    sendTime: Date | undefined;
    createdTime: Date | undefined;
    endTime: Date | undefined;
    acceptedTime: Date | undefined;
    callCenterId: string | undefined;
    caseFolderId: string | undefined;
    transmitterCode: string | undefined;
    alarmCategory: string | undefined;
    alarmEventCode: string | undefined;
    medicalCommander: string | undefined;
    medicalIncidentOfficer: string | undefined;
    attachedCustomerObject: string | undefined;
    alarmEventText: string | undefined;
    additionalInfo: string | undefined;
    keyNumber: string | undefined;
    electronicKey: string | undefined;
    radioGroupMain: string | undefined;
    radioGroupSecondary: string | undefined;
    additionalCoordinationInformation: string | undefined;
    availablePriorities: Array<OperationPriority> | undefined;
    patientName: string | undefined;
    patientUID: string | undefined;
    vehicleStatus: VehicleStatus | undefined;
    destinationSiteLocation: DestinationSiteLocation | undefined;
    breakpointLocation: DestinationControlPointLocation | undefined;
    availableHospitalLocations: Array<HospitalLocation> | undefined;
    header1: string | undefined;
    header2: string | undefined;
    eventInfo: string | undefined;
    caseInfo: string | undefined;
    selectedHospital: number | undefined;
    selectedPriority: number | undefined;
    operationState: OperationState;
    leavePatientLocation: LeavePatientLocation | undefined;
    assignedResourceMissionNo: string | undefined;
    operationUnits: Array<OperationUnit> | undefined;
    prioName: string | undefined;
    /**
     * @param operationID The operation ID
     * @param name The operation name
     * @param sendTime The time at which the operation was sent
     * @param createdTime The time at which the operation was created
     * @param acceptedTime The time at which the operation was accepted (minimum Vehicle Services version: 5.0.2, otherwise always undefined)
     * @param endTime The time at which the operation ended, `undefined` still ongoing
     * @param callCenterId The Call Center ID
     * @param caseFolderId The Case folder ID
     * @param transmitterCode The transmitter code
     * @param alarmCategory The alarm category
     * @param alarmEventCode The alarm event code
     * @param medicalCommander The medical commander of this operation
     * @param medicalIncidentOfficer The medical incident office of this operation
     * @param attachedCustomerObject The attached customer Object
     * @param alarmEventText The alarm event text
     * @param additionalInfo The additional information attached to this operation
     * @param keyNumber The key number
     * @param electronicKey The electronic key
     * @param radioGroupMain The main radio group associated with this operation
     * @param radioGroupSecondary The secondary radio group associated with this operation
     * @param additionalCoordinationInformation Additional coordination information
     * @param availablePriorities The list of available priorities to select from
     * @param patientName The name of the patient if any
     * @param patientUID The personal number of the patient if any
     * @param vehicleStatus The current vehicle status in this operation
     * @param destinationSiteLocation The location of the destination
     * @param breakpointLocation The location of the breakpoint if any
     * @param availableHospitalLocations The list of available hospitals to select from
     * @param header1 The case index 2
     * @param header2 The case index 3
     * @param eventInfo The event description
     * @param caseInfo The case info comment
     * @param selectedHospital The id of the selected hospital [inside available hospitals]
     * @param selectedPriority The id of the selected priority [inside available priority]
     * @param operationState the current state of the operation (ACTIVE, AVAILABLE, COMPLETE)
     * @param leavePatientLocation The location of the leave-patient ('toCity', etc)
     * @param assignedResourceMissionNo The Assigned Resource Mission No value from SOS (minimum Vehicle Services version: 5.2.2, otherwise always undefined)
     * @param operationUnits A list of the units that include the Assigned Resource values from SOS and the Units from the cloud (minimum Vehicle Services version: 5.2.2, otherwise always undefined)
     * @param prioName The operation priority name as it is sent from dispatch, or as it is defined in the Application settings when selected by the user.
     *                 This field is free text and does not adhere to any pattern. Example values include: 1, 1a, 2B, PRIO 1, PRIO 1b, PRIO 2A.
     *                 (minimum Vehicle Services version: 6.1.0, otherwise always undefined)
     */
    constructor(operationID: string, name: string, sendTime: Date | undefined, createdTime: Date | undefined, endTime: Date | undefined, acceptedTime: Date | undefined, callCenterId: string | undefined, caseFolderId: string | undefined, transmitterCode: string | undefined, alarmCategory: string | undefined, alarmEventCode: string | undefined, medicalCommander: string | undefined, // incidentCommander
    medicalIncidentOfficer: string | undefined, attachedCustomerObject: string | undefined, alarmEventText: string | undefined, additionalInfo: string | undefined, keyNumber: string | undefined, electronicKey: string | undefined, radioGroupMain: string | undefined, radioGroupSecondary: string | undefined, additionalCoordinationInformation: string | undefined, availablePriorities: Array<OperationPriority> | undefined, patientName: string | undefined, patientUID: string | undefined, vehicleStatus: VehicleStatus | undefined, destinationSiteLocation: DestinationSiteLocation | undefined, breakpointLocation: DestinationControlPointLocation | undefined, availableHospitalLocations: Array<HospitalLocation> | undefined, header1: string | undefined, header2: string | undefined, eventInfo: string | undefined, caseInfo: string | undefined, selectedHospital: number | undefined, selectedPriority: number | undefined, operationState: OperationState, leavePatientLocation: LeavePatientLocation | undefined, assignedResourceMissionNo: string | undefined, operationUnits: Array<OperationUnit> | undefined, prioName: string | undefined);
    /**
     * Gets the full operation ID, e.g. '1:18:6546', composed by 'callCenterId:caseFolderId:operationID'.
     * @returns id The full operation ID
     */
    getFullId(): string;
    /**
     * Create from JSON
     * @param data JSON object
     */
    static fromJSON(data: any): Operation;
}
export { Operation };
