"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PhoneCall = void 0;
const PhoneCallState_1 = require("./PhoneCallState");
const CallDisconnectCause_1 = require("./CallDisconnectCause");
class PhoneCall {
    /**
     * Model class for the phone call.
     * @param callId the unique id of the call
     * @param callNumber the phone number that the call is connecting to
     * @param callState the state of the call. See {@link PhoneCallState}
     * @param disconnectCause The cause of the termination of a call. See {@link CallDisconnectCause}.
     */
    constructor(callId, callNumber, callState, disconnectCause) {
        this.callId = callId;
        this.callNumber = callNumber;
        this.callState = callState;
        this.disconnectCause = disconnectCause;
    }
    static fromJSON(data) {
        const phoneCallState = PhoneCallState_1.PhoneCallState[data.callState] === undefined ? PhoneCallState_1.PhoneCallState.UNKNOWN : PhoneCallState_1.PhoneCallState[data.callState];
        const disconnectCause = CallDisconnectCause_1.CallDisconnectCause[data.disconnectCause] === undefined ? CallDisconnectCause_1.CallDisconnectCause.UNKNOWN : CallDisconnectCause_1.CallDisconnectCause[data.disconnectCause];
        return new PhoneCall(data.callId, data.callNumber, phoneCallState, disconnectCause);
    }
}
exports.PhoneCall = PhoneCall;
//# sourceMappingURL=PhoneCall.js.map