"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TripLocationHistory = void 0;
const Location_1 = require("./Location");
class TripLocationHistory {
    /**
     * An array of locations represents the history of the trip
     * @param locationHistory location array
     * @param etaSeconds 'estimated time of arrival' in seconds
     * @param distanceToDestinationMeters Remaining driving distance until destination in meters
     */
    constructor(locationHistory, etaSeconds, distanceToDestinationMeters) {
        this.locationHistory = locationHistory;
        this.etaSeconds = etaSeconds;
        this.distanceToDestinationMeters = distanceToDestinationMeters;
    }
    /**
     * Create from JSON
     * @param tripLocationHistory JSON object
     */
    static fromJSON(tripLocationHistory) {
        if (tripLocationHistory.locationHistory === undefined) {
            throw Error("TripLocationHistory must define locationHistory");
        }
        const { locationHistory } = tripLocationHistory;
        if (Array.isArray(locationHistory)) {
            const locationHistoryMapped = locationHistory.map(Location_1.Location.fromJSON);
            return new TripLocationHistory(locationHistoryMapped, tripLocationHistory.etaSeconds, tripLocationHistory.distanceToDestinationMeters);
        }
        else {
            throw Error("TripLocationHistory.locationHistory must be an array");
        }
    }
}
exports.TripLocationHistory = TripLocationHistory;
//# sourceMappingURL=TripLocationHistory.js.map